# airflow-common-operators

Common operators and tasks for Airflow

[![Build Status](https://github.com/airflow-laminar/airflow-common-operators/actions/workflows/build.yaml/badge.svg?branch=main&event=push)](https://github.com/airflow-laminar/airflow-common-operators/actions/workflows/build.yaml)
[![codecov](https://codecov.io/gh/airflow-laminar/airflow-common-operators/branch/main/graph/badge.svg)](https://codecov.io/gh/airflow-laminar/airflow-common-operators)
[![License](https://img.shields.io/github/license/airflow-laminar/airflow-common-operators)](https://github.com/airflow-laminar/airflow-common-operators)
[![PyPI](https://img.shields.io/pypi/v/airflow-common-operators.svg)](https://pypi.python.org/pypi/airflow-common-operators)

## Installation

You can install from pip:

```bash
pip install airflow-common-operators
```

Or via conda:

```bash
conda install airflow-common-operators -c conda-forge
```

## License

This software is licensed under the Apache 2.0 license. See the [LICENSE](LICENSE) file for details.

> [!NOTE]
> This library was generated using [copier](https://copier.readthedocs.io/en/stable/) from the [Base Python Project Template repository](https://github.com/python-project-templates/base).
